#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LOGICAL_XOR_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LOGICAL_XOR_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/logical_xor.hpp>

#endif
